# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.15](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.14...mrml-python-v0.1.15) - 2024-06-30

### Other
- updated the following local packages: mrml

## [0.1.14](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.13...mrml-python-v0.1.14) - 2024-06-13

### Other
- updated the following local packages: mrml

## [0.1.13](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.12...mrml-python-v0.1.13) - 2024-04-20

### Added
- *(mrml-python)* add initial pyi file

### Other
- *(mrml-python)* Bump pyo3 from 0.20.0 to 0.21.2

## [0.1.12](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.11...mrml-python-v0.1.12) - 2024-04-13

### Other
- updated the following local packages: mrml

## [0.1.11](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.10...mrml-python-v0.1.11) - 2024-04-04

### Other
- updated the following local packages: mrml

## [0.1.10](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.9...mrml-python-v0.1.10) - 2024-03-21

### Other
- updated the following local packages: mrml

## [0.1.9](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.8...mrml-python-v0.1.9) - 2024-03-21

### Other
- switch license to MIT ([#388](https://github.com/jdrouet/mrml/pull/388))

## [0.1.8](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.7...mrml-python-v0.1.8) - 2024-03-19

### Other
- updated the following local packages: mrml

## [0.1.7](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.6...mrml-python-v0.1.7) - 2024-03-15

### Other
- updated the following local packages: mrml

## [0.1.6](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.5...mrml-python-v0.1.6) - 2024-03-04

### Other
- updated the following local packages: mrml

## [0.1.5](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.4...mrml-python-v0.1.5) - 2024-03-01

### Added
- *(mrml-python)* implement mj-include ([#381](https://github.com/jdrouet/mrml/pull/381))

## [0.1.4](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.3...mrml-python-v0.1.4) - 2024-02-28

### Other
- updated the following local packages: mrml

## [0.1.3](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.2...mrml-python-v0.1.3) - 2024-02-24

### Other
- updated the following local packages: mrml

## [0.1.2](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.1...mrml-python-v0.1.2) - 2024-02-10

### Other
- updated the following local packages: mrml

## [0.1.1](https://github.com/jdrouet/mrml/compare/mrml-python-v0.1.0...mrml-python-v0.1.1) - 2023-12-19

### Other
- *(mrml-python)* update Cargo.toml
- *(mrml-core)* rename Options to RenderOptions ([#352](https://github.com/jdrouet/mrml/pull/352))
- *(mrml-python)* update readme
- release ([#350](https://github.com/jdrouet/mrml/pull/350))

## [0.1.0](https://github.com/jdrouet/mrml/releases/tag/mrml-python-v0.1.0) - 2023-12-06

### Added
- *(mrml-python)* create python module ([#349](https://github.com/jdrouet/mrml/pull/349))
